==> nextcloud-app-spreed-1%3A8.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/uk.js <==
OC.L10N.register(
    "spreed",
    {
    "None" : "Відсутній",
    "User" : "Користувач",
    "Everyone" : "Всі",
    "Disabled" : "Вимкнено",
    "Users" : "Користувачі",
    "Copy link" : "Скопіювати посилання",
    "Favorite" : "Улюблений",
    "Remove from favorites" : "Видалено з улюбленого",
    "Add to favorites" : "Додати до обраного",
    "Contacts" : "Контакти",
    "Groups" : "Групи",
    "Loading" : "Завантаження",
    "Error" : "Помилка",
    "Password protect" : "Захистити паролем",
    "Back" : "Назад",
    "Close" : "Закрити",
    "Reply" : "Відповісти",
    "Today" : "Сьогодні",
    "Yesterday" : "Вчора",
    "guest" : "гість",
    "No results" : "Немає результатів",
    "Guests" : "Гості",
    "Share link" : "Поширити посилання",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Edit" : "Редашувати",
    "Limit to groups" : "Обмежити групами",
    "Save changes" : "Зберегти зміни",
    "Saved!" : "Збережено!",
    "Name" : "Ім'я",
    "Saved" : "Збережено",
    "Password" : "Пароль",
    "Cancel" : "Скасувати",
    "The password is wrong. Try again." : "Пароль неправильний. Спробуйте ще раз.",
    "Android app" : "Android-додаток",
    "iOS app" : "iOS додаток",
    "Copy" : "Копіювати",
    "Copied!" : "Скопійовано!",
    "Not supported!" : "Не підтримується!",
    "Press ⌘-C to copy." : "Натисніть ⌘-C щоб скопіювати.",
    "Press Ctrl-C to copy." : "Натисніть Ctrl-C щоб скопіювати.",
    "Share" : "Поділитися",
    "Change password" : "Змінити пароль",
    "Rename" : "Перейменувати",
    "Send" : "Надіслати",
    "Error while sharing" : "Помилка при поширенні",
    "Favorited" : "Улюблений",
    ", " : ", "
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-app-spreed-1%3A9.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/uk.js <==
OC.L10N.register(
    "spreed",
    {
    "a conversation" : "розмова",
    "(Duration %s)" : "(Тривалість %s)",
    "Guest" : "Гість",
    "{actor} started a call" : "{actor} розпочав розмову",
    "You started a call" : "Ви почали розмову",
    "{actor} joined the call" : "{actor} приєднався до розмови",
    "You joined the call" : "Ви приєдналися до розмови",
    "{actor} left the call" : "{actor} залишив розмову",
    "You left the call" : "Ви залишили розмову",
    "Limit to groups" : "Обмежити групами",
    "Everyone" : "Всі",
    "Save changes" : "Зберегти зміни",
    "Saving …" : "Збереження ..",
    "Saved!" : "Збережено!",
    "None" : "Відсутній",
    "User" : "Користувач",
    "Disabled" : "Вимкнено",
    "Users" : "Користувачі",
    "Name" : "Ім'я",
    "Off" : "Вимкнути",
    "Saved" : "Збережено",
    "Copy link" : "Скопіювати посилання",
    "Favorite" : "Улюблений",
    "Remove from favorites" : "Видалено з улюбленого",
    "Add to favorites" : "Додати до обраного",
    "Contacts" : "Контакти",
    "Loading" : "Завантаження",
    "Groups" : "Групи",
    "Error" : "Помилка",
    "Password protect" : "Захистити паролем",
    "Back" : "Назад",
    "Close" : "Закрити",
    "Reply" : "Відповісти",
    "Today" : "Сьогодні",
    "Yesterday" : "Вчора",
    "guest" : "гість",
    "No results" : "Немає результатів",
    "Projects" : "Проекти",
    "Settings" : "Налаштування",
    "Edit" : "Редашувати",
    "Dismiss" : "Припинити",
    "Share link" : "Поширити посилання",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Grid view" : "Упорядкування у формі сітки",
    "The password is wrong. Try again." : "Пароль неправильний. Спробуйте ще раз.",
    "Password" : "Пароль",
    "Android app" : "Android-додаток",
    "iOS app" : "iOS додаток",
    "Copy" : "Копіювати",
    "Copied!" : "Скопійовано!",
    "Not supported!" : "Не підтримується!",
    "Press ⌘-C to copy." : "Натисніть ⌘-C щоб скопіювати.",
    "Press Ctrl-C to copy." : "Натисніть Ctrl-C щоб скопіювати.",
    "Password required" : "Зазначте пароль",
    "Cancel" : "Скасувати",
    "Guests" : "Гості",
    "Change password" : "Змінити пароль",
    "Rename" : "Перейменувати",
    "Send" : "Надіслати",
    "Share" : "Поділитися",
    "Error while sharing" : "Помилка при поширенні",
    "Favorited" : "Улюблений"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
